@@ -259,6 +259,9 @@ class API(object):
 
         if compression and compression in accepted_compression:
             messageData["headers"]["Content-Encoding"] = compression
+            if isinstance(response_body, str):
+                response_body = bytes(response_body, "utf-8")
+
             if compression == "gzip":
                 gzip_compress = zlib.compressobj(9, zlib.DEFLATED, zlib.MAX_WBITS | 16)
                 response_body = (
@@ -283,7 +286,9 @@ class API(object):
                     ),
                 )
 
-        if content_type in binary_types and b64encode:
+        if (
+            content_type in binary_types or not isinstance(response_body, str)
+        ) and b64encode:
             messageData["isBase64Encoded"] = True
             messageData["body"] = base64.b64encode(response_body).decode()
         else:
